package betterquesting.client.importers;

import betterquesting.api.questing.IQuest;
import betterquesting.api.questing.IQuestDatabase;
import betterquesting.api2.storage.DBEntry;
import betterquesting.api2.storage.SimpleDatabase;
import betterquesting.questing.QuestInstance;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.UUID;
import net.minecraft.nbt.NBTBase;
import net.minecraft.nbt.NBTTagCompound;
import net.minecraft.nbt.NBTTagList;

/* loaded from: betterquesting_client_importers.jar:betterquesting/client/importers/ImportedQuests.class */
public class ImportedQuests extends SimpleDatabase<IQuest> implements IQuestDatabase {
    public /* bridge */ /* synthetic */ NBTBase writeToNBT(NBTBase nBTBase, List list) {
        return writeToNBT((NBTTagList) nBTBase, (List<Integer>) list);
    }

    public /* bridge */ /* synthetic */ NBTBase writeProgressToNBT(NBTBase nBTBase, List list) {
        return writeProgressToNBT((NBTTagList) nBTBase, (List<UUID>) list);
    }

    public IQuest createNew(int id) {
        return (IQuest) add(id, new QuestInstance()).getValue();
    }

    public synchronized List<DBEntry<IQuest>> bulkLookup(int... ids) {
        if (ids == null || ids.length <= 0) {
            return Collections.emptyList();
        }
        List<DBEntry<IQuest>> values = new ArrayList<>();
        for (int i : ids) {
            IQuest v = (IQuest) getValue(i);
            if (v != null) {
                values.add(new DBEntry<>(i, v));
            }
        }
        return values;
    }

    public NBTTagList writeToNBT(NBTTagList nbt, List<Integer> subset) {
        for (DBEntry<IQuest> entry : getEntries()) {
            if (subset == null || subset.contains(Integer.valueOf(entry.getID()))) {
                NBTTagCompound jq = new NBTTagCompound();
                ((IQuest) entry.getValue()).writeToNBT(jq);
                jq.func_74768_a("questID", entry.getID());
                nbt.func_74742_a(jq);
            }
        }
        return nbt;
    }

    public void readFromNBT(NBTTagList nbt, boolean merge) {
        if (!merge) {
            reset();
        }
        for (int i = 0; i < nbt.func_74745_c(); i++) {
            NBTTagCompound qTag = nbt.func_150305_b(i);
            int qID = qTag.func_150297_b("questID", 99) ? qTag.func_74762_e("questID") : -1;
            if (qID >= 0) {
                IQuest quest = (IQuest) getValue(qID);
                (quest != null ? quest : createNew(qID)).readFromNBT(qTag);
            }
        }
    }

    public NBTTagList writeProgressToNBT(NBTTagList nbt, List<UUID> users) {
        return nbt;
    }

    public void readProgressFromNBT(NBTTagList nbt, boolean merge) {
    }
}
